class Config {
	static Language := "en"
	, Options := {ValidateOnParse: 0
		, AllowDocumentFunction: 0
		, AllowXsltScript: 0
		, ProhibitDTD: 1
		, ResolveExternals: 0
		, UseInlineSchema: 0}
	, Settings := {XsltList: []
		, XsltSelectedRow: 0
		, ParameterSelection: {}}
	
	Init()
	{
		if FileExist(A_ScriptDir "\xsl-transformer.ini") {
			this.GetIniLanguage()
			this.GetIniOption("ValidateOnParse")
			this.GetIniOption("AllowDocumentFunction")
			this.GetIniOption("AllowXsltScript")
			this.GetIniOption("ProhibitDTD")
			this.GetIniOption("ResolveExternals")
			this.GetIniOption("UseInlineSchema")
		}
	}
	
	GetIniOption(Key)
	{
		IniRead, Option, % A_ScriptDir "\xsl-transformer.ini", XslTransformerOptions, % Key
		if (Option != "ERROR") {
			this.Options[Key := Option]
		}
	}
	
	GetIniLanguage()
	{
		IniRead, LangID, % A_ScriptDir "\xsl-transformer.ini", XslTransformerLanguage, LanguageID
		if (LangID != "ERROR") {
			this.Language := LangID
		}
	}
	
	ValidateOnParse[]
	{
		get {
			return this.Options.ValidateOnParse
		}
	}
	
	AllowDocumentFunction[]
	{
		get {
			return this.Options.AllowDocumentFunction
		}
	}
	
	AllowXsltScript[]
	{
		get {
			return this.Options.AllowXsltScript
		}
	}
	
	ProhibitDTD[]
	{
		get {
			return this.Options.ProhibitDTD
		}
	}
	
	ResolveExternals[]
	{
		get {
			return this.Options.ResolveExternals
		}
	}
	
	UseInlineSchema[]
	{
		get {
			return this.Options.UseInlineSchema
		}
	}
	
	XsltList[Mode = ""]
	{
		get {
			if (Mode = "CompleteList") {
				return this.Settings.XsltList
			} else {
				StylesheetList := []
				for key, item in this.Settings.XsltList {
					StylesheetList.Push(item.Path)
				}
				return StylesheetList
			}
		}
		set {
			this.Settings.XsltList := value
		}
	}
	
	XsltListItem[Mode := "Add", Num := 0]
	{
		set {
			if (Mode = "Add") {
				OutputMethod := Xml.GetXsltOutputMethod(value)
				if (Num != 0) {
					this.Settings.XsltList.InsertAt(Num + 1, {Path: value, OutputMethod: OutputMethod, Parameter: {}})
				} else {
					this.Settings.XsltList.Push({Path: value, OutputMethod: OutputMethod, Parameter: {}})
				}
			} else if (Mode = "Remove") {
				this.Settings.XsltList.RemoveAt(value)
			} else if (Mode = "Up" or Mode = "Down") {
				Item := this.Settings.XsltList.RemoveAt(value)
				NewPos := (Mode = "Up") ? value - 1 : value + 1
				this.Settings.XsltList.InsertAt(NewPos, Item)
			}
		}
	}
	
	XsltSelectedRow[]
	{
		get {
			return this.Settings.XsltSelectedRow
		}
		set {
			this.Settings.XsltSelectedRow := value
		}
	}
	
	ParameterList[StylesheetIndex]
	{
		get {
			return this.Settings.XsltList[StylesheetIndex].Parameter
		}
	}
	
	ParameterListItem[StylesheetIndex, ParameterKey, Mode := "AddOrEdit"]
	{
		get {
			return this.Settings.XsltList[StylesheetIndex].Parameter[ParameterKey]
		}
		set {
			if (Mode = "AddOrEdit") {
				this.Settings.XsltList[StylesheetIndex].Parameter[ParameterKey] := value
			} else if (Mode = "Remove" or Mode = "Delete") {
				this.Settings.XsltList[StylesheetIndex].Parameter.Delete(ParameterKey)
			}
		}
	}
	
	ParameterSelection[]
	{
		get {
			return this.Settings.ParameterSelection
		}
		set {
			this.Settings.ParameterSelection := value
		}
	}
}